@@ -1,7 +1,8 @@
 plugin_search_plos <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("plos", sources))) {
     opts$q <- query
-    opts$limit <- limit
+    if (is.null(opts$limit)) opts$limit <- limit
+    if (is.null(opts$start)) opts$start <- start
     opts$callopts <- list(...)
     out <- do.call(searchplos, opts)
     zz <- list(source = "plos", found = out$meta$numFound, data = out$data,
@@ -27,12 +28,12 @@ plugin_search_plos <- function(sources, query, limit, start, opts, ...){
 plugin_search_crossref <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("crossref", sources))) {
     opts$query <- query
-    opts$limit <- limit
-    opts$offset <- start
+    if (is.null(opts$limit)) opts$limit <- limit
+    if (is.null(opts$offset)) opts$offset <- start
     if ("filter" %in% names(opts)) {
       opts$filter <- c(c(has_license = TRUE), opts$filter)
     } else {
-      opts$filter <- c(has_license = TRUE)  
+      opts$filter <- c(has_license = TRUE)
     }
     opts <- c(opts, ...)
     out <- do.call(cr_works, opts)
@@ -49,13 +50,14 @@ plugin_search_crossref <- function(sources, query, limit, start, opts, ...){
 plugin_search_bmc <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("bmc", sources))) {
     opts$query <- query
-    opts$limit <- limit
+    if (is.null(opts$limit)) opts$limit <- limit
+    if (is.null(opts$offset)) opts$offset <- start
     opts <- c(opts, ...)
     out <- do.call(bmc_search, opts)
     dat <- out$records
     dat <- names_lower(dat)
     opts$query <- NULL
-    zz <- list(source = "bmc", found = out$result$total, data = dat, opts = opts, 
+    zz <- list(source = "bmc", found = out$result$total, data = dat, opts = opts,
                license = list(type = "variable, see `openaccess` field in results"))
     structure(zz, class = "ft_ind", query = query)
   } else {
@@ -68,7 +70,8 @@ plugin_search_entrez <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("entrez", sources))) {
     opts$db <- "pmc"
     opts$term <- query
-    opts$retmax <- limit
+    if (is.null(opts$retmax)) opts$retmax <- limit
+    if (is.null(opts$retstart)) opts$retstart <- start
     out <- do.call(entrez_search, opts)
     sumres <- rentrez::entrez_summary(db = "pmc", id = out$ids, config = c(...))
     dat <- lapply(sumres, function(x) {
@@ -98,8 +101,9 @@ plugin_search_europe_pmc <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("europmc", sources))) {
     opts$query <- query
     opts <- c(opts, ...)
+    if (is.null(opts$per_page)) opts$per_page <- limit
     out <- do.call(eupmc_search, opts)
-    zz <- list(source = "europmc", found = out$hitCount, 
+    zz <- list(source = "europmc", found = out$hitCount,
                data = out$resultList$result, opts = opts,
                cursorMark = out$nextCursorMark)
     structure(zz, class = "ft_ind", query = query)
@@ -112,7 +116,8 @@ plugin_search_europe_pmc <- function(sources, query, limit, start, opts, ...){
 plugin_search_arxiv <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("arxiv", sources))) {
     opts$query <- query
-    opts$limit <- limit
+    if (is.null(opts$limit)) opts$limit <- limit
+    if (is.null(opts$start)) opts$start <- start
     out <- do.call(aRxiv::arxiv_search, opts)
     out <- names_lower(out)
     zz <- list(source = "arxiv", found = attributes(out)$total_results, data = out, opts = opts,
@@ -127,11 +132,11 @@ plugin_search_arxiv <- function(sources, query, limit, start, opts, ...){
 plugin_search_biorxivr <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("biorxiv", sources))) {
     opts$query <- query
-    opts$limit <- limit
+    if (is.null(opts$limit)) opts$limit <- limit
     opts <- c(opts, ...)
     out <- do.call(biorxiv_search, opts)
     out$data <- names_lower(out$data)
-    zz <- list(source = "biorxiv", found = out$found, data = out$data, opts = opts, 
+    zz <- list(source = "biorxiv", found = out$found, data = out$data, opts = opts,
                license = list(type = "variable, but free to text-mine, see http://biorxiv.org/about-biorxiv"))
     structure(zz, class = "ft_ind", query = query)
   } else {
@@ -143,15 +148,15 @@ plugin_search_biorxivr <- function(sources, query, limit, start, opts, ...){
 plugin_search_scopus <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("scopus", sources))) {
     opts$query <- query
-    opts$count <- limit
-    opts$start <- start
+    if (is.null(opts$count)) opts$count <- limit
+    if (is.null(opts$start)) opts$start <- start
     opts <- c(opts, ...)
     out <- do.call(scopus_search_loop, opts)
     df <- out$results
     df$`@_fa` <- df$link <- NULL
-    zz <- list(source = "scopus", 
+    zz <- list(source = "scopus",
                found = out$found,
-               data = df, 
+               data = df,
                facets = out$facets,
                opts = opts)
     structure(zz, class = "ft_ind", query = query)
@@ -164,13 +169,13 @@ plugin_search_scopus <- function(sources, query, limit, start, opts, ...){
 plugin_search_ma <- function(sources, query, limit, start, opts, ...){
   if (any(grepl("microsoft", sources))) {
     opts$query <- query
-    opts$count <- limit
-    opts$offset <- start
+    if (is.null(opts$count)) opts$count <- limit
+    if (is.null(opts$offset)) opts$offset <- start
     opts <- c(opts, ...)
     out <- do.call(microsoft_search, opts)
-    zz <- list(source = "microsoft", 
+    zz <- list(source = "microsoft",
                found = NULL,
-               data = out, 
+               data = out,
                opts = opts)
     structure(zz, class = "ft_ind", query = query)
   } else {
